mysql.exceptions.internal.No_More_Rows

Package mysql :: Package exceptions :: Module internal :: Class No_More_Rows |
[hide private]
[frames] | no frames]

# Class No_More_Rows

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              No_More_Rows

The last row was reached in the mysql.result.Result.fetch_row method.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`